@@ -328,7 +328,8 @@ def bulk(traces, dest, split=1000, stream='raw', fname=safe_name, write=to_file,
     :param split: max number of files per directory (when set to `None`, all
         files will be saved to the same directory)
     :param stream: stream name to read from the traces, optionally supplied as
-        a `callable` returning the stream name;
+        a `callable` returning the stream name (*trace* will be omitted from
+        export if the return value is falsy);
         passed kwargs: *trace*
     :param fname: `callable` to generate a file name for a trace;
         passed kwargs: *trace*, *num*, *split*, *stream* (defaults to
@@ -372,6 +373,12 @@ def bulk(traces, dest, split=1000, stream='raw', fname=safe_name, write=to_file,
         for num, trace in enumerate(traces):
             # resolve stream if caller wants to decide which one to select
             selected_stream = stream(trace=trace) if callable(stream) else stream
+            if not selected_stream:
+                # user-supplied stream selector returned a falsy value, that won't be something we can export
+                # drop this trace from the export tasks, but warn about it
+                log.warn('omitting trace {} from bulk export, no stream to export was selected', trace.get('uid'))
+                continue
+
             # determine folder number only if a split is requested
             folder = num // split if split else None
             file = fname(trace=trace, num=num, split=split, stream=selected_stream)
